@@ -2,6 +2,7 @@
 
 import attr
 from functools import wraps, total_ordering
+from inspect import getfullargspec as getargspec
 import logging
 import os
 import re
@@ -11,10 +12,9 @@ import warnings
 from rasterio._env import (
         GDALEnv, get_gdal_config, set_gdal_config,
         GDALDataFinder, PROJDataFinder, set_proj_data_search_path)
-from rasterio.compat import string_types, getargspec
 from rasterio.errors import (
     EnvError, GDALVersionError, RasterioDeprecationWarning)
-from rasterio.session import Session, AWSSession, DummySession
+from rasterio.session import Session, DummySession
 
 
 class ThreadEnv(threading.local):
@@ -51,12 +51,6 @@ local = ThreadEnv()
 
 log = logging.getLogger(__name__)
 
-try:
-    import boto3
-except ImportError:
-    log.info("failed to import boto3, continuing.")
-    boto3 = None
-
 
 class Env(object):
     """Abstraction for GDAL and AWS configuration
@@ -72,11 +66,13 @@ class Env(object):
     is exited, drivers are removed from the registry and other
     configurations are removed.
 
-    Example:
+    Example
+    -------
+    .. code-block:: python
 
-        with rasterio.Env(GDAL_CACHEMAX=512) as env:
+        with rasterio.Env(GDAL_CACHEMAX=128000000) as env:
             # All drivers are registered, GDAL's raster block cache
-            # size is set to 512MB.
+            # size is set to 128 MB.
             # Commence processing...
             ...
             # End of processing.
@@ -104,13 +100,12 @@ class Env(object):
         dict
         """
         return {
-            'CHECK_WITH_INVERT_PROJ': True,
             'GTIFF_IMPLICIT_JPEG_OVR': False,
             "RASTERIO_ENV": True
         }
 
     def __init__(self, session=None, aws_unsigned=False, profile_name=None,
-                 session_class=AWSSession, **options):
+                 session_class=Session.aws_or_dummy, **options):
         """Create a new GDAL/AWS environment.
 
         Note: this class is a context manager. GDAL isn't configured
@@ -187,12 +182,12 @@ class Env(object):
                     "AWSSession object instead.",
                     RasterioDeprecationWarning
                 )
-                session = AWSSession(session=session)
+                session = Session.aws_or_dummy(session=session)
 
             self.session = session
 
         elif aws_access_key_id or profile_name or aws_unsigned:
-            self.session = AWSSession(
+            self.session = Session.aws_or_dummy(
                 aws_access_key_id=aws_access_key_id,
                 aws_secret_access_key=aws_secret_access_key,
                 aws_session_token=aws_session_token,
@@ -200,13 +195,8 @@ class Env(object):
                 profile_name=profile_name,
                 aws_unsigned=aws_unsigned)
 
-        elif 'AWS_ACCESS_KEY_ID' in os.environ and 'AWS_SECRET_ACCESS_KEY' in os.environ and boto3 is not None:
-            try:
-                self.session = AWSSession()
-                self.session.credentials
-            except RuntimeError as exc:
-                log.info("No AWS session created. Credentials in environment have expired.")
-                self.session = DummySession()
+        elif 'AWS_ACCESS_KEY_ID' in os.environ and 'AWS_SECRET_ACCESS_KEY' in os.environ:
+            self.session = Session.from_environ()
 
         else:
             self.session = DummySession()
@@ -489,7 +479,7 @@ class GDALVersion(object):
             return input
         if isinstance(input, tuple):
             return cls(*input)
-        elif isinstance(input, string_types):
+        elif isinstance(input, str):
             # Extract major and minor version components.
             # alpha, beta, rc suffixes ignored
             match = re.search(r'^\d+\.\d+', input)
@@ -649,6 +639,11 @@ if "PROJ_LIB" in os.environ:
     path = os.environ["PROJ_LIB"]
     set_proj_data_search_path(path)
 
+elif PROJDataFinder().search_wheel():
+    path = PROJDataFinder().search_wheel()
+    log.debug("PROJ data found in wheel, setting to %r.", path)
+    set_proj_data_search_path(path)
+
 # See https://github.com/mapbox/rasterio/issues/1631.
 elif PROJDataFinder().has_data():
     log.debug("PROJ data files are available at built-in paths")
