@@ -295,7 +295,9 @@ def rasterize(
         if is_valid_geom(geom):
             shape_values.append(value)
 
-            if geom['type'] == 'GeometryCollection':
+            geom_type = geom['type']
+
+            if geom_type == 'GeometryCollection':
                 # GeometryCollections need to be handled as individual parts to
                 # avoid holes in output:
                 # https://github.com/mapbox/rasterio/issues/1253.
@@ -304,6 +306,11 @@ def rasterize(
                 for part in geom['geometries']:
                     valid_shapes.append((part, value))
 
+            elif geom_type == 'MultiPolygon':
+                # Same issue as above
+                for poly in geom['coordinates']:
+                    valid_shapes.append(({'type': 'Polygon', 'coordinates': poly}, value))
+
             else:
                 valid_shapes.append((geom, value))
 
