@@ -1,12 +1,15 @@
 """Copy valid pixels from input files to an output file."""
 
-
+from contextlib import contextmanager
 import logging
 import math
+from pathlib import Path
 import warnings
 
 import numpy as np
 
+import rasterio
+from rasterio.enums import Resampling
 from rasterio import windows
 from rasterio.transform import Affine
 
@@ -16,8 +19,20 @@ logger = logging.getLogger(__name__)
 MERGE_METHODS = ('first', 'last', 'min', 'max')
 
 
-def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10,
-          indexes=None, output_count=None, method='first'):
+def merge(
+    datasets,
+    bounds=None,
+    res=None,
+    nodata=None,
+    dtype=None,
+    precision=10,
+    indexes=None,
+    output_count=None,
+    resampling=Resampling.nearest,
+    method="first",
+    dst_path=None,
+    dst_kwds=None,
+):
     """Copy valid pixels from input files to an output file.
 
     All files must have the same number of bands, data type, and
@@ -33,7 +48,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
 
     Parameters
     ----------
-    datasets: list of dataset objects opened in 'r' mode
+    datasets : list of dataset objects opened in 'r' mode, filenames or pathlib.Path objects
         source datasets to be merged.
     bounds: tuple, optional
         Bounds of the output image (left, bottom, right, top).
@@ -55,6 +70,9 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
     output_count: int, optional
         If using callable it may be useful to have additional bands in the output
         in addition to the indexes specified for read
+    resampling : Resampling, optional
+        Resampling algorithm used when reading input files.
+        Default: `Resampling.nearest`.
     method : str or callable
         pre-defined method:
             first: reverse painting
@@ -81,6 +99,11 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
                 row offset in base array
             coff: int
                 column offset in base array
+    dst_path : str or Pathlike, optional
+        Path of output dataset
+    dst_kwds : dict, optional
+        Dictionary of creation options and other paramters that will be
+        overlaid on the profile of the output dataset.
 
     Returns
     -------
@@ -94,23 +117,43 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
             out_transform: affine.Affine()
                 Information for mapping pixel coordinates in `dest` to another
                 coordinate system
-    """
-    first = datasets[0]
-    first_res = first.res
-    nodataval = first.nodatavals[0]
-    dt = first.dtypes[0]
 
+    """
     if method not in MERGE_METHODS and not callable(method):
         raise ValueError('Unknown method {0}, must be one of {1} or callable'
                          .format(method, MERGE_METHODS))
 
-    # Determine output band count
-    if indexes is None:
-        src_count = first.count
-    elif isinstance(indexes, int):
-        src_count = indexes
+    # Create a dataset_opener object to use in several places in this function.
+    if isinstance(datasets[0], str) or isinstance(datasets[0], Path):
+        dataset_opener = rasterio.open
     else:
-        src_count = len(indexes)
+
+        @contextmanager
+        def nullcontext(obj):
+            try:
+                yield obj
+            finally:
+                pass
+
+        dataset_opener = nullcontext
+
+    with dataset_opener(datasets[0]) as first:
+        first_profile = first.profile
+        first_res = first.res
+        nodataval = first.nodatavals[0]
+        dt = first.dtypes[0]
+
+        if indexes is None:
+            src_count = first.count
+        elif isinstance(indexes, int):
+            src_count = indexes
+        else:
+            src_count = len(indexes)
+
+        try:
+            first_colormap = first.colormap(1)
+        except ValueError:
+            first_colormap = None
 
     if not output_count:
         output_count = src_count
@@ -122,8 +165,9 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
         # scan input files
         xs = []
         ys = []
-        for src in datasets:
-            left, bottom, right, top = src.bounds
+        for dataset in datasets:
+            with dataset_opener(dataset) as src:
+                left, bottom, right, top = src.bounds
             xs.extend([left, right])
             ys.extend([bottom, top])
         dst_w, dst_s, dst_e, dst_n = min(xs), min(ys), max(xs), max(ys)
@@ -156,6 +200,16 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
         dt = dtype
         logger.debug("Set dtype: %s", dt)
 
+    out_profile = first_profile
+    out_profile.update(**(dst_kwds or {}))
+
+    out_profile["transform"] = output_transform
+    out_profile["height"] = output_height
+    out_profile["width"] = output_width
+    out_profile["count"] = output_count
+    if nodata is not None:
+        out_profile["nodata"] = nodata
+
     # create destination array
     dest = np.zeros((output_count, output_height, output_width), dtype=dt)
 
@@ -218,36 +272,44 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
     else:
         raise ValueError(method)
 
-    for idx, src in enumerate(datasets):
-        # Real World (tm) use of boundless reads.
-        # This approach uses the maximum amount of memory to solve the
-        # problem. Making it more efficient is a TODO.
+    for idx, dataset in enumerate(datasets):
+        with dataset_opener(dataset) as src:
+            # Real World (tm) use of boundless reads.
+            # This approach uses the maximum amount of memory to solve the
+            # problem. Making it more efficient is a TODO.
 
-        # 1. Compute spatial intersection of destination and source
-        src_w, src_s, src_e, src_n = src.bounds
+            # 1. Compute spatial intersection of destination and source
+            src_w, src_s, src_e, src_n = src.bounds
 
-        int_w = src_w if src_w > dst_w else dst_w
-        int_s = src_s if src_s > dst_s else dst_s
-        int_e = src_e if src_e < dst_e else dst_e
-        int_n = src_n if src_n < dst_n else dst_n
+            int_w = src_w if src_w > dst_w else dst_w
+            int_s = src_s if src_s > dst_s else dst_s
+            int_e = src_e if src_e < dst_e else dst_e
+            int_n = src_n if src_n < dst_n else dst_n
 
-        # 2. Compute the source window
-        src_window = windows.from_bounds(
-            int_w, int_s, int_e, int_n, src.transform, precision=precision)
-        logger.debug("Src %s window: %r", src.name, src_window)
+            # 2. Compute the source window
+            src_window = windows.from_bounds(
+                int_w, int_s, int_e, int_n, src.transform, precision=precision
+            )
+            logger.debug("Src %s window: %r", src.name, src_window)
 
-        src_window = src_window.round_shape()
+            src_window = src_window.round_shape()
 
-        # 3. Compute the destination window
-        dst_window = windows.from_bounds(
-            int_w, int_s, int_e, int_n, output_transform, precision=precision)
+            # 3. Compute the destination window
+            dst_window = windows.from_bounds(
+                int_w, int_s, int_e, int_n, output_transform, precision=precision
+            )
 
-        # 4. Read data in source window into temp
-        trows, tcols = (
-            int(round(dst_window.height)), int(round(dst_window.width)))
-        temp_shape = (src_count, trows, tcols)
-        temp = src.read(out_shape=temp_shape, window=src_window,
-                        boundless=False, masked=True, indexes=indexes)
+            # 4. Read data in source window into temp
+            trows, tcols = (int(round(dst_window.height)), int(round(dst_window.width)))
+            temp_shape = (src_count, trows, tcols)
+            temp = src.read(
+                out_shape=temp_shape,
+                window=src_window,
+                boundless=False,
+                masked=True,
+                indexes=indexes,
+                resampling=resampling,
+            )
 
         # 5. Copy elements of temp into dest
         roff, coff = (
@@ -264,4 +326,11 @@ def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10
         copyto(region, temp, region_nodata, temp_nodata,
                index=idx, roff=roff, coff=coff)
 
-    return dest, output_transform
+    if dst_path is None:
+        return dest, output_transform
+
+    else:
+        with rasterio.open(dst_path, "w", **out_profile) as dst:
+            dst.write(dest)
+            if first_colormap:
+                dst.write_colormap(1, first_colormap)
