@@ -1,27 +1,27 @@
 import json
 import logging
-import shutil
 
 import click
-import cligj
 
 from .helpers import resolve_inout
 from . import options
 import rasterio
+import rasterio.shutil
+from rasterio.mask import mask as mask_tool
 
-logger = logging.getLogger('rio')
+logger = logging.getLogger(__name__)
 
 
 # Mask command
 @click.command(short_help='Mask in raster using features.')
-@cligj.files_inout_arg
+@options.files_inout_arg
 @options.output_opt
 @click.option('-j', '--geojson-mask', 'geojson_mask',
               type=click.Path(), default=None,
               help='GeoJSON file to use for masking raster.  Use "-" to read '
                    'from stdin.  If not provided, original raster will be '
                    'returned')
-@cligj.format_opt
+@options.format_opt
 @options.all_touched_opt
 @click.option('--crop', is_flag=True, default=False,
               help='Crop output raster to the extent of the geometries. '
@@ -30,7 +30,7 @@ logger = logging.getLogger('rio')
               help='Inverts the mask, so that areas covered by features are'
                    'masked out and areas not covered are retained.  Ignored '
                    'if using --crop')
-@options.force_overwrite_opt
+@options.overwrite_opt
 @options.creation_options
 @click.pass_context
 def mask(
@@ -42,7 +42,7 @@ def mask(
         all_touched,
         crop,
         invert,
-        force_overwrite,
+        overwrite,
         creation_options):
     """Masks in raster using GeoJSON features (masks out all areas not covered
     by features), and optionally crops the output raster to the extent of the
@@ -65,26 +65,22 @@ def mask(
     --crop option is not valid if features are completely outside extent of
     input raster.
     """
-    from rasterio.mask import mask as mask_tool
-    from rasterio.features import bounds as calculate_bounds
-
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
 
     output, files = resolve_inout(
-        files=files, output=output, force_overwrite=force_overwrite)
+        files=files, output=output, overwrite=overwrite)
     input = files[0]
 
     if geojson_mask is None:
         click.echo('No GeoJSON provided, INPUT will be copied to OUTPUT',
                    err=True)
-        shutil.copy(input, output)
+        rasterio.shutil.copyfiles(input, output)
         return
 
     if crop and invert:
         click.echo('Invert option ignored when using --crop', err=True)
         invert = False
 
-    with rasterio.Env(CPL_DEBUG=verbosity > 2):
+    with ctx.obj['env']:
         try:
             with click.open_file(geojson_mask) as fh:
                 geojson = json.loads(fh.read())
@@ -114,15 +110,20 @@ def mask(
                                                  'input raster',
                                                  param=crop,
                                                  param_hint='--crop')
+                else:  # pragma: no cover
+                    raise e
 
-            meta = src.meta.copy()
-            meta.update(**creation_options)
-            meta.update({
+            profile = src.profile
+            profile.update(**creation_options)
+            profile.pop("driver", None)
+            if driver:
+                profile["driver"] = driver
+            profile.update({
                 'driver': driver,
                 'height': out_image.shape[1],
                 'width': out_image.shape[2],
                 'transform': out_transform
             })
 
-            with rasterio.open(output, 'w', **meta) as out:
+            with rasterio.open(output, 'w', **profile) as out:
                 out.write(out_image)
