@@ -2,12 +2,11 @@
 
 import json
 import logging
-import os
 
 import click
 from cligj import precision_opt
 
-import rasterio
+import rasterio.shutil
 
 
 @click.command(short_help="Transform coordinates.")
@@ -21,8 +20,7 @@ import rasterio
 def transform(ctx, input, src_crs, dst_crs, precision):
     import rasterio.warp
 
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-    logger = logging.getLogger('rio')
+    logger = logging.getLogger(__name__)
 
     # Handle the case of file, stream, or string input.
     try:
@@ -31,15 +29,15 @@ def transform(ctx, input, src_crs, dst_crs, precision):
         src = [input]
 
     try:
-        with rasterio.Env(CPL_DEBUG=verbosity > 2):
+        with ctx.obj['env']:
             if src_crs.startswith('EPSG'):
                 src_crs = {'init': src_crs}
-            elif os.path.exists(src_crs):
+            elif rasterio.shutil.exists(src_crs):
                 with rasterio.open(src_crs) as f:
                     src_crs = f.crs
             if dst_crs.startswith('EPSG'):
                 dst_crs = {'init': dst_crs}
-            elif os.path.exists(dst_crs):
+            elif rasterio.shutil.exists(dst_crs):
                 with rasterio.open(dst_crs) as f:
                     dst_crs = f.crs
             for line in src:
