@@ -1,8 +1,20 @@
 """Abstraction for sessions in various clouds."""
 
+import logging
+import os
+
 from rasterio.path import parse_path, UnparsedPath
 
 
+log = logging.getLogger(__name__)
+
+try:
+    import boto3
+except ImportError:
+    log.debug("Could not import boto3, continuing with reduced functionality.")
+    boto3 = None
+
+
 class Session(object):
     """Base for classes that configure access to secured resources.
 
@@ -89,7 +101,11 @@ class Session(object):
             return DummySession
 
         elif path.scheme == "s3" or "amazonaws.com" in path.path:
-            return AWSSession
+            if boto3 is not None:
+                return AWSSession
+            else:
+                log.info("boto3 not available, falling back to a DummySession.")
+                return DummySession
 
         elif path.scheme == "oss" or "aliyuncs.com" in path.path:
             return OSSSession
@@ -97,6 +113,9 @@ class Session(object):
         elif path.path.startswith("/vsiswift/"):
             return SwiftSession
 
+        elif path.scheme == "az":
+            return AzureSession
+
         # This factory can be extended to other cloud providers here.
         # elif path.scheme == "cumulonimbus":  # for example.
         #     return CumulonimbusSession(*args, **kwargs)
@@ -124,6 +143,55 @@ class Session(object):
         """
         return Session.cls_from_path(path)(*args, **kwargs)
 
+    @staticmethod
+    def aws_or_dummy(*args, **kwargs):
+        """Create an AWSSession if boto3 is available, else DummySession
+
+        Parameters
+        ----------
+        path : str
+            A dataset path or identifier.
+        args : sequence
+            Positional arguments for the foreign session constructor.
+        kwargs : dict
+            Keyword arguments for the foreign session constructor.
+
+        Returns
+        -------
+        Session
+
+        """
+        if boto3 is not None:
+            return AWSSession(*args, **kwargs)
+        else:
+            return DummySession(*args, **kwargs)
+
+    @staticmethod
+    def from_environ(*args, **kwargs):
+        """Create a session object suited to the environment.
+
+        Parameters
+        ----------
+        path : str
+            A dataset path or identifier.
+        args : sequence
+            Positional arguments for the foreign session constructor.
+        kwargs : dict
+            Keyword arguments for the foreign session constructor.
+
+        Returns
+        -------
+        Session
+
+        """
+        try:
+            session = Session.aws_or_dummy(*args, **kwargs)
+            session.credentials
+        except RuntimeError as exc:
+            log.warning("Credentials in environment have expired. Creating a DummySession.")
+            session = DummySession(*args, **kwargs)
+        return session
+
 
 class DummySession(Session):
     """A dummy session.
@@ -177,7 +245,7 @@ class AWSSession(Session):
             aws_secret_access_key=None, aws_session_token=None,
             region_name=None, profile_name=None, endpoint_url=None,
             requester_pays=False):
-        """Create a new boto3 session
+        """Create a new AWS session
 
         Parameters
         ----------
@@ -201,8 +269,6 @@ class AWSSession(Session):
             True if the requester agrees to pay transfer costs (default:
             False)
         """
-        import boto3
-
         if session:
             self._session = session
         else:
@@ -214,9 +280,13 @@ class AWSSession(Session):
                 profile_name=profile_name)
 
         self.requester_pays = requester_pays
-        self.unsigned = aws_unsigned
+        self.unsigned = bool(os.getenv("AWS_NO_SIGN_REQUEST", aws_unsigned))
         self.endpoint_url = endpoint_url
-        self._creds = self._session._session.get_credentials() if self._session else None
+        self._creds = (
+            self._session._session.get_credentials()
+            if not self.unsigned and self._session
+            else None
+        )
 
     @classmethod
     def hascreds(cls, config):
@@ -240,7 +310,7 @@ class AWSSession(Session):
     def credentials(self):
         """The session credentials as a dict"""
         res = {}
-        if self._creds: # pragma: no branch
+        if self._creds:  # pragma: no branch
             frozen_creds = self._creds.get_frozen_credentials()
             if frozen_creds.access_key:  # pragma: no branch
                 res['aws_access_key_id'] = frozen_creds.access_key
@@ -276,16 +346,16 @@ class AWSSession(Session):
 class OSSSession(Session):
     """Configures access to secured resources stored in Alibaba Cloud OSS.
     """
-    def __init__(self, oss_access_key_id, oss_secret_access_key, oss_endpoint='oss-us-east-1.aliyuncs.com'):
+    def __init__(self, oss_access_key_id=None, oss_secret_access_key=None, oss_endpoint=None):
         """Create new Alibaba Cloud OSS session
 
         Parameters
         ----------
-        oss_access_key_id: string
+        oss_access_key_id: string, optional (default: None)
             An access key id
-        oss_secret_access_key: string
+        oss_secret_access_key: string, optional (default: None)
             An secret access key
-        oss_endpoint: string, default 'oss-us-east-1.aliyuncs.com'
+        oss_endpoint: string, optional (default: None)
             the region attached to the bucket
         """
 
@@ -294,7 +364,7 @@ class OSSSession(Session):
             "oss_secret_access_key": oss_secret_access_key,
             "oss_endpoint": oss_endpoint
         }
-    
+
     @classmethod
     def hascreds(cls, config):
         """Determine if the given configuration has proper credentials
@@ -383,14 +453,15 @@ class GSSession(Session):
 class SwiftSession(Session):
     """Configures access to secured resources stored in OpenStack Swift Object Storage.
     """
-    def __init__(self, session=None, 
-                swift_storage_url=None, swift_auth_token=None, 
+    def __init__(self, session=None,
+                swift_storage_url=None, swift_auth_token=None,
                 swift_auth_v1_url=None, swift_user=None, swift_key=None):
-        """Create new OpenStack Swift Object Storage Session.   
-        Three methods are possible:  
+        """Create new OpenStack Swift Object Storage Session.
+
+        Three methods are possible:
             1. Create session by the swiftclient library.
-            2. The SWIFT_STORAGE_URL and SWIFT_AUTH_TOKEN (this method is recommended by GDAL docs).  
-            3. The SWIFT_AUTH_V1_URL, SWIFT_USER and SWIFT_KEY (This depends on the swiftclient library).  
+            2. The SWIFT_STORAGE_URL and SWIFT_AUTH_TOKEN (this method is recommended by GDAL docs).
+            3. The SWIFT_AUTH_V1_URL, SWIFT_USER and SWIFT_KEY (This depends on the swiftclient library).
 
         Parameters
         ----------
@@ -439,7 +510,7 @@ class SwiftSession(Session):
                 "swift_storage_url": self._session.get_auth()[0],
                 "swift_auth_token": self._session.get_auth()[1]
             }
-            
+
     @classmethod
     def hascreds(cls, config):
         """Determine if the given configuration has proper credentials
@@ -467,4 +538,66 @@ class SwiftSession(Session):
         dict
         """
         return {k.upper(): v for k, v in self.credentials.items()}
-        
+
+
+class AzureSession(Session):
+    """Configures access to secured resources stored in Microsoft Azure Blob Storage.
+    """
+    def __init__(self, azure_storage_connection_string=None,
+                 azure_storage_account=None, azure_storage_access_key=None):
+        """Create new Microsoft Azure Blob Storage session
+
+        Parameters
+        ----------
+        azure_storage_connection_string: string
+            A connection string contains both an account name and a secret key.
+        azure_storage_account: string
+            An account name
+        azure_storage_access_key: string
+            A secret key
+        """
+
+        if azure_storage_connection_string:
+            self._creds = {
+                "azure_storage_connection_string": azure_storage_connection_string
+            }
+        else:
+            self._creds = {
+                "azure_storage_account": azure_storage_account,
+                "azure_storage_access_key": azure_storage_access_key
+            }
+
+    @classmethod
+    def hascreds(cls, config):
+        """Determine if the given configuration has proper credentials
+
+        Parameters
+        ----------
+        cls : class
+            A Session class.
+        config : dict
+            GDAL configuration as a dict.
+
+        Returns
+        -------
+        bool
+
+        """
+        return 'AZURE_STORAGE_CONNECTION_STRING' in config or (
+            'AZURE_STORAGE_ACCOUNT' in config and 'AZURE_STORAGE_ACCESS_KEY' in config
+        )
+
+    @property
+    def credentials(self):
+        """The session credentials as a dict"""
+        return self._creds
+
+    def get_credential_options(self):
+        """Get credentials as GDAL configuration options
+
+        Returns
+        -------
+        dict
+
+        """
+        return {k.upper(): v for k, v in self.credentials.items()}
