@@ -1,13 +1,11 @@
 """Geospatial transforms"""
 
-from __future__ import division
-
+from collections.abc import Iterable
 import math
 
 from affine import Affine
 
-from rasterio.compat import Iterable
-
+from rasterio._transform import _transform_from_gcps
 
 IDENTITY = Affine.identity()
 GDAL_IDENTITY = IDENTITY.to_gdal()
@@ -249,3 +247,19 @@ def rowcol(transform, xs, ys, op=math.floor, precision=None):
         rows = rows[0]
 
     return rows, cols
+
+
+def from_gcps(gcps):
+    """Make an Affine transform from ground control points.
+
+    Parameters
+    ----------
+    gcps : sequence of GroundControlPoint
+        Such as the first item of a dataset's `gcps` property.
+
+    Returns
+    -------
+    Affine
+
+    """
+    return Affine.from_gdal(*_transform_from_gcps(gcps))
