@@ -17,8 +17,8 @@ The newer float precision read-write window capabilities of Rasterio
 require instances of Window to be used.
 """
 
-from __future__ import division
 import collections
+from collections.abc import Iterable
 import functools
 import math
 import warnings
@@ -27,7 +27,6 @@ import attr
 from affine import Affine
 import numpy as np
 
-from rasterio.compat import Iterable
 from rasterio.errors import WindowError
 from rasterio.transform import rowcol, guard_transform
 
@@ -258,13 +257,20 @@ def from_bounds(left, bottom, right, top, transform=None,
 
     Parameters
     ----------
-    left, bottom, right, top: float
-        Left (west), bottom (south), right (east), and top (north)
-        bounding coordinates.
-    transform: Affine
+    left: float, required
+        Left (west) bounding coordinates
+    bottom: float, required
+        Bottom (south) bounding coordinates
+    right: float, required
+        Right (east) bounding coordinates
+    top: float, required
+        Top (north) bounding coordinates
+    transform: Affine, required
         Affine transform matrix.
-    height, width: int
-        Number of rows and columns of the window.
+    height: int, required
+        Number of rows of the window.
+    width: int, required
+        Number of columns of the window.
     precision: int, optional
         Number of decimal points of precision when computing inverse
         transform.
@@ -272,8 +278,17 @@ def from_bounds(left, bottom, right, top, transform=None,
     Returns
     -------
     Window
-        A new Window
+        A new Window.
+
+    Raises
+    ------
+    WindowError
+        If a window can't be calculated.
+
     """
+    if not isinstance(transform, Affine):  # TODO: RPCs?
+        raise WindowError("A transform object is required to calculate the window")
+
     row_start, col_start = rowcol(
         transform, left, top, op=float, precision=precision)
 
