@@ -1,12 +1,9 @@
 import json
 
-from click.testing import CliRunner
 import pytest
 
-import numpy as np
 import rasterio
 from rasterio.rio.main import main_group
-from rasterio.env import GDALVersion
 
 from .conftest import requires_gdal21, requires_gdal23
 
@@ -15,8 +12,7 @@ with rasterio.Env() as env:
     HAVE_NETCDF = 'NetCDF' in env.drivers().keys()
 
 
-def test_env():
-    runner = CliRunner()
+def test_env(runner):
     result = runner.invoke(main_group, [
         'env',
         '--formats'
@@ -25,17 +21,15 @@ def test_env():
     assert 'GTiff' in result.output
 
 
-def test_info_err():
+def test_info_err(runner):
     """Trying to get info of a directory raises an exception"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['info', 'tests'])
     assert result.exit_code != 0
     assert result.exception
 
 
-def test_info():
-    runner = CliRunner()
+def test_info(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
@@ -53,44 +47,39 @@ def test_info():
     assert info['crs'] is None
 
 
-def test_info_units():
+def test_info_units(runner):
     """Find a units item"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"units": [null, null, null]' in result.output
 
 
-def test_info_indexes():
+def test_info_indexes(runner):
     """Find an indexes item"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"indexes": [1, 2, 3]' in result.output
 
 
-def test_info_descriptions():
+def test_info_descriptions(runner):
     """Find description items"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"descriptions"' in result.output
 
 
-def test_info_mask_flags():
+def test_info_mask_flags(runner):
     """Find description items"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"mask_flags": [["nodata"], ["nodata"], ["nodata"]]' in result.output
 
 
-def test_info_verbose():
-    runner = CliRunner()
+def test_info_verbose(runner):
     result = runner.invoke(main_group, [
         '-v',
         'info',
@@ -99,8 +88,7 @@ def test_info_verbose():
     assert result.exit_code == 0
 
 
-def test_info_quiet():
-    runner = CliRunner()
+def test_info_quiet(runner):
     result = runner.invoke(main_group, [
         '-q',
         'info',
@@ -109,8 +97,7 @@ def test_info_quiet():
     assert result.exit_code == 0
 
 
-def test_info_gcps():
-    runner = CliRunner()
+def test_info_gcps(runner):
     result = runner.invoke(main_group, [
         'info',
         'tests/data/white-gemini-iv.vrt'
@@ -118,56 +105,49 @@ def test_info_gcps():
     assert result.exit_code == 0
 
 
-def test_info_count():
-    runner = CliRunner()
+def test_info_count(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--count'])
     assert result.exit_code == 0
     assert result.output == '3\n'
 
 
-def test_info_nodatavals():
-    runner = CliRunner()
+def test_info_nodatavals(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--bounds'])
     assert result.exit_code == 0
     assert result.output == '101985.0 2611485.0 339315.0 2826915.0\n'
 
 
-def test_info_tags():
-    runner = CliRunner()
+def test_info_tags(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--tags'])
     assert result.exit_code == 0
     assert result.output == '{"AREA_OR_POINT": "Area"}\n'
 
 
-def test_info_res():
-    runner = CliRunner()
+def test_info_res(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--res'])
     assert result.exit_code == 0
     assert result.output.startswith('300.037')
 
 
-def test_info_lnglat():
-    runner = CliRunner()
+def test_info_lnglat(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--lnglat'])
     assert result.exit_code == 0
     assert result.output.startswith('-77.757')
 
 
-def test_mo_info():
-    runner = CliRunner()
+def test_mo_info(runner):
     result = runner.invoke(main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"res": [300.037' in result.output
     assert '"lnglat": [-77.757' in result.output
 
 
-def test_info_stats():
-    runner = CliRunner()
+def test_info_stats(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--tell-me-more'])
     assert result.exit_code == 0
@@ -176,8 +156,7 @@ def test_info_stats():
     assert '"mean": 44.4344' in result.output
 
 
-def test_info_stats_only():
-    runner = CliRunner()
+def test_info_stats_only(runner):
     result = runner.invoke(
         main_group,
         ['info', 'tests/data/RGB.byte.tif', '--stats', '--bidx', '2'])
@@ -185,23 +164,20 @@ def test_info_stats_only():
     assert result.output.startswith('1.000000 255.000000 66.02')
 
 
-def test_info_colorinterp():
-    runner = CliRunner()
+def test_info_colorinterp(runner):
     result = runner.invoke(main_group, ['info', 'tests/data/alpha.tif'])
     assert result.exit_code == 0
     assert '"colorinterp": ["red", "green", "blue", "alpha"]' in result.output
 
 
-def test_transform_err():
-    runner = CliRunner()
+def test_transform_err(runner):
     result = runner.invoke(main_group, [
         'transform'
     ], "[-78.0]")
     assert result.exit_code == 1
 
 
-def test_transform_point():
-    runner = CliRunner()
+def test_transform_point(runner):
     result = runner.invoke(main_group, [
         'transform',
         '--dst-crs', 'EPSG:32618',
@@ -211,8 +187,7 @@ def test_transform_point():
     assert result.output.strip() == '[192457.13, 2546667.68]'
 
 
-def test_transform_point_dst_file():
-    runner = CliRunner()
+def test_transform_point_dst_file(runner):
     result = runner.invoke(main_group, [
         'transform',
         '--dst-crs', 'tests/data/RGB.byte.tif', '--precision', '2'
@@ -221,8 +196,7 @@ def test_transform_point_dst_file():
     assert result.output.strip() == '[192457.13, 2546667.68]'
 
 
-def test_transform_point_src_file():
-    runner = CliRunner()
+def test_transform_point_src_file(runner):
     result = runner.invoke(main_group, [
         'transform',
         '--src-crs',
@@ -233,8 +207,7 @@ def test_transform_point_src_file():
     assert result.output.strip() == '[-78.0, 23.0]'
 
 
-def test_transform_point_2():
-    runner = CliRunner()
+def test_transform_point_2(runner):
     result = runner.invoke(main_group, [
         'transform',
         '[-78.0, 23.0]',
@@ -245,8 +218,7 @@ def test_transform_point_2():
     assert result.output.strip() == '[192457.13, 2546667.68]'
 
 
-def test_transform_point_multi():
-    runner = CliRunner()
+def test_transform_point_multi(runner):
     result = runner.invoke(main_group, [
         'transform',
         '--dst-crs', 'EPSG:32618',
@@ -257,8 +229,7 @@ def test_transform_point_multi():
         '[192457.13, 2546667.68]\n[192457.13, 2546667.68]')
 
 
-def test_bounds_defaults():
-    runner = CliRunner()
+def test_bounds_defaults(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif'
@@ -267,8 +238,7 @@ def test_bounds_defaults():
     assert 'Feature' in result.output
 
 
-def test_bounds_err():
-    runner = CliRunner()
+def test_bounds_err(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests'
@@ -276,8 +246,7 @@ def test_bounds_err():
     assert result.exit_code == 1
 
 
-def test_bounds_feature():
-    runner = CliRunner()
+def test_bounds_feature(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -287,8 +256,7 @@ def test_bounds_feature():
     assert result.output.count('Polygon') == 1
 
 
-def test_bounds_obj_bbox():
-    runner = CliRunner()
+def test_bounds_obj_bbox(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -299,8 +267,7 @@ def test_bounds_obj_bbox():
     assert result.output.strip() == '[-78.96, 23.56, -76.57, 25.55]'
 
 
-def test_bounds_compact():
-    runner = CliRunner()
+def test_bounds_compact(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -312,8 +279,7 @@ def test_bounds_compact():
     assert result.output.strip() == '[-78.96,23.56,-76.57,25.55]'
 
 
-def test_bounds_indent():
-    runner = CliRunner()
+def test_bounds_indent(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -325,8 +291,7 @@ def test_bounds_indent():
     assert len(result.output.split('\n')) == 7
 
 
-def test_bounds_obj_bbox_mercator():
-    runner = CliRunner()
+def test_bounds_obj_bbox_mercator(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -339,8 +304,7 @@ def test_bounds_obj_bbox_mercator():
         '[-8789636.708, 2700489.278, -8524281.514, 2943560.235]')
 
 
-def test_bounds_obj_bbox_projected():
-    runner = CliRunner()
+def test_bounds_obj_bbox_projected(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -353,8 +317,7 @@ def test_bounds_obj_bbox_projected():
         '[101985.0, 2611485.0, 339315.0, 2826915.0]')
 
 
-def test_bounds_crs_bbox():
-    runner = CliRunner()
+def test_bounds_crs_bbox(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -367,8 +330,7 @@ def test_bounds_crs_bbox():
         '[101985.0, 2611485.0, 339315.0, 2826915.0]')
 
 
-def test_bounds_seq():
-    runner = CliRunner()
+def test_bounds_seq(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -392,8 +354,7 @@ def test_bounds_seq():
     assert '\x1e' not in result.output
 
 
-def test_bounds_seq_rs():
-    runner = CliRunner()
+def test_bounds_seq_rs(runner):
     result = runner.invoke(main_group, [
         'bounds',
         'tests/data/RGB.byte.tif',
@@ -409,28 +370,24 @@ def test_bounds_seq_rs():
         '\x1e[-78.96, 23.56, -76.57, 25.55]\n')
 
 
-def test_insp():
-    runner = CliRunner()
+def test_insp(runner):
     result = runner.invoke(main_group, ['insp', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
 
 
-def test_insp_err():
-    runner = CliRunner()
+def test_insp_err(runner):
     result = runner.invoke(main_group, ['insp', 'tests'])
     assert result.exit_code != 0
 
 
-def test_info_checksums():
-    runner = CliRunner()
+def test_info_checksums(runner):
     result = runner.invoke(
         main_group, ['info', 'tests/data/RGB.byte.tif', '--tell-me-more'])
     assert result.exit_code == 0
     assert '"checksum": [25420, 29131, 37860]' in result.output
 
 
-def test_info_checksums_only():
-    runner = CliRunner()
+def test_info_checksums_only(runner):
     result = runner.invoke(
         main_group,
         ['info', 'tests/data/RGB.byte.tif', '--checksum', '--bidx', '2'])
@@ -441,8 +398,7 @@ def test_info_checksums_only():
 @requires_gdal21(reason="NetCDF requires GDAL 2.1+")
 @pytest.mark.skipif(not HAVE_NETCDF,
                     reason="GDAL not compiled with NetCDF driver.")
-def test_info_subdatasets():
-    runner = CliRunner()
+def test_info_subdatasets(runner):
     result = runner.invoke(
         main_group,
         ['info', 'netcdf:tests/data/RGB.nc', '--subdatasets'])
@@ -451,11 +407,10 @@ def test_info_subdatasets():
     assert result.output.startswith('netcdf:tests/data/RGB.nc:Band1')
 
 
-def test_info_no_credentials(tmpdir, monkeypatch):
+def test_info_no_credentials(tmpdir, monkeypatch, runner):
     credentials_file = tmpdir.join('credentials')
     monkeypatch.setenv('AWS_SHARED_CREDENTIALS_FILE', str(credentials_file))
     monkeypatch.delenv('AWS_ACCESS_KEY_ID', raising=False)
-    runner = CliRunner()
     result = runner.invoke(
         main_group,
         ['info', 'tests/data/RGB.byte.tif'])
@@ -464,8 +419,7 @@ def test_info_no_credentials(tmpdir, monkeypatch):
 
 @requires_gdal23(reason="Unsigned S3 requests require GDAL ~= 2.3")
 @pytest.mark.network
-def test_info_aws_unsigned():
+def test_info_aws_unsigned(runner):
     """Unsigned access to public dataset works (see #1637)"""
-    runner = CliRunner()
     result = runner.invoke(main_group, ['--aws-no-sign-requests', 'info', 's3://landsat-pds/L8/139/045/LC81390452014295LGN00/LC81390452014295LGN00_B1.TIF'])
     assert result.exit_code == 0
