@@ -12,6 +12,7 @@ from pytest import fixture
 import pytest
 
 import rasterio
+from rasterio import Path
 from rasterio.enums import Resampling
 from rasterio.merge import merge
 from rasterio.rio.main import main_group
@@ -102,7 +103,7 @@ def test_data_dir_3(tmpdir):
     return tmpdir
 
 
-def test_merge_with_colormap(test_data_dir_1):
+def test_merge_with_colormap(test_data_dir_1, runner):
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
     inputs.sort()
@@ -111,7 +112,6 @@ def test_merge_with_colormap(test_data_dir_1):
         with rasterio.open(inputname, 'r+') as src:
             src.write_colormap(1, {0: (255, 0, 0, 255), 255: (0, 0, 0, 255)})
 
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
     assert os.path.exists(outputname)
@@ -124,11 +124,10 @@ def test_merge_with_colormap(test_data_dir_1):
 
 @requires_gdal22(
     reason="This test is sensitive to pixel values and requires GDAL 2.2+")
-def test_merge_with_nodata(test_data_dir_1):
+def test_merge_with_nodata(test_data_dir_1, runner):
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
     assert os.path.exists(outputname)
@@ -142,22 +141,20 @@ def test_merge_with_nodata(test_data_dir_1):
 
 
 @pytest.mark.filterwarnings("ignore:Input file's nodata value")
-def test_merge_error(test_data_dir_1):
+def test_merge_error(test_data_dir_1, runner):
     """A nodata value outside the valid range results in an error"""
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['merge'] + inputs + [outputname] + ['--nodata', '-1'])
     assert result.exit_code
 
 
-def test_merge_bidx(test_data_dir_3):
+def test_merge_bidx(test_data_dir_3, runner):
     outputname = str(test_data_dir_3.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_3.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['merge'] + inputs + [outputname] + ['--bidx', '1'])
     assert result.exit_code == 0
@@ -170,11 +167,10 @@ def test_merge_bidx(test_data_dir_3):
 
 @requires_gdal22(
     reason="This test is sensitive to pixel values and requires GDAL 2.2+")
-def test_merge_without_nodata(test_data_dir_2):
+def test_merge_without_nodata(test_data_dir_2, runner):
     outputname = str(test_data_dir_2.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_2.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
     assert os.path.exists(outputname)
@@ -187,9 +183,8 @@ def test_merge_without_nodata(test_data_dir_2):
         assert np.all(data == expected)
 
 
-def test_merge_output_exists(tmpdir):
+def test_merge_output_exists(tmpdir, runner):
     outputname = str(tmpdir.join('merged.tif'))
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['merge', 'tests/data/RGB.byte.tif', outputname])
     assert result.exit_code == 0
@@ -200,9 +195,8 @@ def test_merge_output_exists(tmpdir):
         assert out.count == 3
 
 
-def test_merge_output_exists_without_nodata_fails(test_data_dir_2):
+def test_merge_output_exists_without_nodata_fails(test_data_dir_2, runner):
     """Fails without --overwrite"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, [
             'merge', str(test_data_dir_2.join('a.tif')),
@@ -210,9 +204,8 @@ def test_merge_output_exists_without_nodata_fails(test_data_dir_2):
     assert result.exit_code == 1
 
 
-def test_merge_output_exists_without_nodata(test_data_dir_2):
+def test_merge_output_exists_without_nodata(test_data_dir_2, runner):
     """Succeeds with --overwrite"""
-    runner = CliRunner()
     result = runner.invoke(
         main_group, [
             'merge', '--overwrite', str(test_data_dir_2.join('a.tif')),
@@ -220,16 +213,14 @@ def test_merge_output_exists_without_nodata(test_data_dir_2):
     assert result.exit_code == 0
 
 
-def test_merge_err():
-    runner = CliRunner()
+def test_merge_err(runner):
     result = runner.invoke(
         main_group, ['merge', 'tests'])
     assert result.exit_code == 1
 
 
-def test_format_jpeg(tmpdir):
+def test_format_jpeg(tmpdir, runner):
     outputname = str(tmpdir.join('stacked.jpg'))
-    runner = CliRunner()
     result = runner.invoke(
         main_group, [
             'merge', 'tests/data/RGB.byte.tif', outputname,
@@ -267,11 +258,10 @@ def test_data_dir_overlapping(tmpdir):
     return tmpdir
 
 
-def test_merge_overlapping(test_data_dir_overlapping):
+def test_merge_overlapping(test_data_dir_overlapping, runner):
     outputname = str(test_data_dir_overlapping.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_overlapping.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
     assert os.path.exists(outputname)
@@ -350,11 +340,10 @@ def test_data_dir_float(tmpdir):
 
 @requires_gdal22(
     reason="This test is sensitive to pixel values and requires GDAL 2.2+")
-def test_merge_float(test_data_dir_float):
+def test_merge_float(test_data_dir_float, runner):
     outputname = str(test_data_dir_float.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_float.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['merge'] + inputs + [outputname] + ['--nodata', '-1.5'])
     assert result.exit_code == 0
@@ -406,11 +395,10 @@ def tiffs(tmpdir):
     return tmpdir
 
 
-def test_merge_tiny_base(tiffs):
+def test_merge_tiny_base(tiffs, runner):
     outputname = str(tiffs.join('merged.tif'))
     inputs = [str(x) for x in tiffs.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
 
@@ -430,11 +418,10 @@ def test_merge_tiny_base(tiffs):
         assert data[0][3][0] == 40
 
 
-def test_merge_tiny_output_opt(tiffs):
+def test_merge_tiny_output_opt(tiffs, runner):
     outputname = str(tiffs.join('merged.tif'))
     inputs = [str(x) for x in tiffs.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + ['-o', outputname])
     assert result.exit_code == 0
 
@@ -457,11 +444,10 @@ def test_merge_tiny_output_opt(tiffs):
     reason="This test is sensitive to pixel values and requires GDAL 2.2+")
 @pytest.mark.xfail(sys.version_info < (3,),
                    reason="Test is sensitive to rounding behavior")
-def test_merge_tiny_res_bounds(tiffs):
+def test_merge_tiny_res_bounds(tiffs, runner):
     outputname = str(tiffs.join('merged.tif'))
     inputs = [str(x) for x in tiffs.listdir()]
     inputs.sort()
-    runner = CliRunner()
     result = runner.invoke(
         main_group, ['merge'] + inputs + [outputname, '--res', 2, '--bounds', '1, 0, 5, 4'])
     assert result.exit_code == 0
@@ -483,7 +469,7 @@ def test_merge_tiny_res_bounds(tiffs):
     gdal_version.major == 1,
     reason="GDAL versions < 2 do not support data read/write with float sizes and offsets",
 )
-def test_merge_rgb(tmpdir):
+def test_merge_rgb(tmpdir, runner):
     """Get back original image"""
     outputname = str(tmpdir.join('merged.tif'))
     inputs = [
@@ -491,7 +477,6 @@ def test_merge_rgb(tmpdir):
         'tests/data/rgb2.tif',
         'tests/data/rgb3.tif',
         'tests/data/rgb4.tif']
-    runner = CliRunner()
     result = runner.invoke(main_group, ['merge'] + inputs + [outputname])
     assert result.exit_code == 0
 
@@ -559,12 +544,81 @@ def test_merge_precision(tmpdir, precision):
     assert open(outputname).read() == textwrap.dedent(expected)
 
 
+@fixture(scope='function')
+def test_data_dir_resampling(tmpdir):
+    kwargs = {
+        "crs": {'init': 'epsg:4326'},
+        "transform": affine.Affine(0.2, 0, 0,
+                                   0, -0.2, 0),
+        "count": 1,
+        "dtype": rasterio.uint8,
+        "driver": "GTiff",
+        "width": 9,
+        "height": 1,
+        "nodata": 1
+    }
+
+    with rasterio.open(str(tmpdir.join('a.tif')), 'w', **kwargs) as dst:
+        data = np.ones((1, 9), dtype=rasterio.uint8)
+        data[:, :3] = 100
+        data[:, 3:6] = 255
+        dst.write(data, indexes=1)
+
+    return tmpdir
+
+
+@pytest.mark.parametrize(
+    "resampling",
+    [resamp for resamp in Resampling if resamp < 7] +
+    [pytest.param(Resampling.gauss, marks=pytest.mark.xfail)]
+)
+def test_merge_resampling(test_data_dir_resampling, resampling, runner):
+    outputname = str(test_data_dir_resampling.join('merged.tif'))
+    inputs = [str(x) for x in test_data_dir_resampling.listdir()]
+    with rasterio.open(inputs[0]) as src:
+        bounds = src.bounds
+        res = src.res[0]
+        expected_raster = src.read(
+            out_shape=tuple(dim * 2 for dim in src.shape),
+            resampling=resampling
+        )
+    result = runner.invoke(
+        main_group, ['merge'] + inputs + [outputname] +
+        ['--res', res / 2, '--resampling', resampling.name] +
+        ['--bounds', ' '.join(map(str, bounds))])
+    assert result.exit_code == 0
+    assert os.path.exists(outputname)
+    with rasterio.open(outputname) as dst:
+        output_raster = dst.read()
+
+    np.testing.assert_array_equal(output_raster, expected_raster)
+
+
 def test_merge_filenames(tiffs):
     inputs = [str(x) for x in tiffs.listdir()]
     inputs.sort()
     merge(inputs, res=2)
 
 
+def test_merge_pathlib_path(tiffs):
+    inputs = [Path(x) for x in tiffs.listdir()]
+    inputs.sort()
+    merge(inputs, res=2)
+
+
+def test_merge_output_dataset(tiffs, tmpdir):
+    """Write to an open dataset"""
+    inputs = [str(x) for x in tiffs.listdir()]
+    inputs.sort()
+    output_file = tmpdir.join("output.tif")
+    merge(inputs, res=2, dst_path=str(output_file), dst_kwds=dict(driver="PNG"))
+
+    with rasterio.open(str(output_file)) as result:
+        assert result.count == 1
+        assert result.driver == "PNG"
+        assert result.height == result.width == 2
+
+
 @fixture(scope='function')
 def test_data_dir_resampling(tmpdir):
     kwargs = {
