@@ -7,7 +7,15 @@ try:
 except ImportError:
     import mock
 
-from rasterio.session import DummySession, AWSSession, Session, OSSSession, GSSession, SwiftSession
+from rasterio.session import (
+    DummySession,
+    AWSSession,
+    Session,
+    OSSSession,
+    GSSession,
+    SwiftSession,
+    AzureSession,
+)
 
 
 def test_base_session_hascreds_notimpl():
@@ -236,3 +244,36 @@ def test_no_credentialization_if_unsigned(monkeypatch):
     """Don't get credentials if we're not signing, see #1984"""
     sesh = AWSSession(aws_unsigned=True)
     assert sesh._creds is None
+
+
+def test_azure_session_class():
+    """AzureSession works"""
+    azure_session = AzureSession(azure_storage_account='foo', azure_storage_access_key='bar')
+    assert azure_session._creds
+    assert azure_session.get_credential_options()['AZURE_STORAGE_ACCOUNT'] == 'foo'
+    assert azure_session.get_credential_options()['AZURE_STORAGE_ACCESS_KEY'] == 'bar'
+
+
+def test_azure_session_class_connection_string():
+    """AzureSession works"""
+    azure_session = AzureSession(azure_storage_connection_string='AccountName=myaccount;AccountKey=MY_ACCOUNT_KEY')
+    assert azure_session._creds
+    assert (
+        azure_session.get_credential_options()['AZURE_STORAGE_CONNECTION_STRING']
+        == 'AccountName=myaccount;AccountKey=MY_ACCOUNT_KEY'
+    )
+
+
+def test_session_factory_az_kwargs():
+    """Get an AzureSession for az:// paths with keywords"""
+    sesh = Session.from_path("az://lol/wut", azure_storage_account='foo', azure_storage_access_key='bar')
+    assert isinstance(sesh, AzureSession)
+    assert sesh.get_credential_options()['AZURE_STORAGE_ACCOUNT'] == 'foo'
+    assert sesh.get_credential_options()['AZURE_STORAGE_ACCESS_KEY'] == 'bar'
+
+
+def test_session_factory_az_kwargs_connection_string():
+    """Get an AzureSession for az:// paths with keywords"""
+    sesh = Session.from_path("az://lol/wut", azure_storage_connection_string='AccountName=myaccount;AccountKey=MY_ACCOUNT_KEY')
+    assert isinstance(sesh, AzureSession)
+    assert sesh.get_credential_options()['AZURE_STORAGE_CONNECTION_STRING'] == 'AccountName=myaccount;AccountKey=MY_ACCOUNT_KEY'
\ No newline at end of file
