@@ -2,6 +2,7 @@
 
 import json
 import sys
+import logging
 
 from affine import Affine
 import numpy as np
@@ -33,6 +34,7 @@ from rasterio import windows
 
 from .conftest import requires_gdal22, requires_gdal3, requires_gdal_lt_3
 
+log = logging.getLogger(__name__)
 
 gdal_version = GDALVersion.runtime()
 
@@ -1066,6 +1068,37 @@ def test_transform_geom_multipolygon(polygon_3373):
     assert all(round(x, 1) == x for x in flatten_coords(result["coordinates"]))
 
 
+def test_transform_geom_array(polygon_3373):
+    geom = [polygon_3373 for _ in range(10)]
+    result = transform_geom("EPSG:3373", "EPSG:4326", geom, precision=1)
+    assert isinstance(result, list)
+    assert len(result) == 10
+
+
+def test_transform_geom__geo_interface(polygon_3373):
+    class GeoObj:
+        @property
+        def __geo_interface__(self):
+            return polygon_3373
+
+    result = transform_geom("EPSG:3373", "EPSG:4326", GeoObj(), precision=1)
+    assert all(round(x, 1) == x for x in flatten_coords(result["coordinates"]))
+
+
+def test_transform_geom__geo_interface__array(polygon_3373):
+    class GeoObj:
+        @property
+        def __geo_interface__(self):
+            return polygon_3373
+
+    geom = [GeoObj() for _ in range(10)]
+    results = transform_geom("EPSG:3373", "EPSG:4326", geom, precision=1)
+    assert isinstance(results, list)
+    assert len(results) == 10
+    for result in results:
+        assert all(round(x, 1) == x for x in flatten_coords(result["coordinates"]))
+
+
 @pytest.mark.parametrize("method", SUPPORTED_RESAMPLING)
 def test_reproject_resampling(path_rgb_byte_tif, method):
     # Expected count of nonzero pixels for each resampling method, based
@@ -1083,6 +1116,7 @@ def test_reproject_resampling(path_rgb_byte_tif, method):
         Resampling.med: [437194],
         Resampling.q1: [436397],
         Resampling.q3: [438948],
+        Resampling.rms: [439385],
     }
 
     with rasterio.open(path_rgb_byte_tif) as src:
@@ -1173,6 +1207,7 @@ def test_reproject_resampling_alpha(method):
         Resampling.med: [437194],
         Resampling.q1: [436397],
         Resampling.q3: [438948],
+        Resampling.rms: [439385],
     }
 
     with rasterio.open("tests/data/RGBA.byte.tif") as src:
@@ -1513,7 +1548,6 @@ def test_transform_geom_gdal22():
 def test_issue1056():
     """Warp sucessfully from RGB's upper bands to an array"""
     with rasterio.open("tests/data/RGB.byte.tif") as src:
-
         dst_crs = "EPSG:3857"
         out = np.zeros(src.shape, dtype=np.uint8)
         reproject(
@@ -1716,3 +1750,191 @@ def test_empty_transform_inputs_length_z():
     """Get an exception of inputs have different lengths"""
     with pytest.raises(TransformError):
         rasterio.warp.transform("EPSG:3857", "EPSG:4326", [1, 2], [1, 2], zs=[0])
+
+
+def test_reproject_rpcs(caplog):
+    """Reproject using rational polynomial coefficients for the source"""
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        out = np.zeros(
+            (3, src.profile["width"], src.profile["height"]), dtype=np.uint8
+        )
+        src_rpcs = src.rpcs
+        reproject(
+            rasterio.band(src, src.indexes),
+            out,
+            src_crs="EPSG:4326",
+            rpcs=src_rpcs,
+            dst_crs="EPSG:3857",
+            resampling=Resampling.nearest,
+        )
+
+        assert not out.all()
+        assert not out[:, 0, 0].any()
+        assert not out[:, 0, -1].any()
+        assert not out[:, -1, -1].any()
+        assert not out[:, -1, 0].any()
+
+
+def test_reproject_rpcs_with_transformer_options(caplog):
+    """Reproject using rational polynomial coefficients and additional transformer options"""
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        with rasterio.MemoryFile(dirname='foo', filename='dem.tif') as mem:
+            crs = 'COMPD_CS["WGS 84 + EGM96 height",GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AXIS["Latitude",NORTH],AXIS["Longitude",EAST],AUTHORITY["EPSG","4326"]],VERT_CS["EGM96 height",VERT_DATUM["EGM96 geoid",2005,AUTHORITY["EPSG","5171"]],UNIT["metre",1,AUTHORITY["EPSG","9001"]],AXIS["Gravity-related height",UP],AUTHORITY["EPSG","5773"]]]'
+            transform = Affine(0.001953396267361111, 0.0, -124.00013888888888, 0.0, -0.001953396267361111, 50.000138888888884)
+            with mem.open(
+                driver="GTiff",
+                width=1024, 
+                height=1024, 
+                count=1,
+                transform=transform,
+                dtype='int16', 
+                crs=crs
+            ) as dem:
+                # we flush dem dataset before letting GDAL read from vsimem
+                dem.write_band(1, 500 * np.ones((1024, 1024), dtype='int16'))
+            
+            out = np.zeros(
+                (3, src.profile["width"], src.profile["height"]), dtype=np.uint8
+            )
+            out2 = out.copy()
+            src_rpcs = src.rpcs
+            caplog.set_level(logging.DEBUG)
+            reproject(
+                rasterio.band(src, src.indexes),
+                out,
+                src_crs="EPSG:4326",
+                rpcs=src_rpcs,
+                dst_crs="EPSG:3857",
+                resampling=Resampling.nearest,
+                RPC_DEM=dem.name,
+
+            )   
+            caplog.set_level(logging.INFO)
+            reproject(
+                rasterio.band(src, src.indexes),
+                out2,
+                src_crs="EPSG:4326",
+                rpcs=src_rpcs,
+                dst_crs="EPSG:3857",
+                resampling=Resampling.nearest,
+
+            ) 
+            
+            assert not out.all()
+            assert not out2.all()
+            assert "RPC_DEM" in caplog.text
+            assert not np.array_equal(out, out2)
+
+
+def test_warp_gcps_compute_dst_transform_automatically_array():
+    """Ensure we don't raise an exception when gcps passed without dst_transform, for a source array"""
+    source = np.ones((3, 800, 800), dtype=np.uint8) * 255
+    out = np.zeros((3, 512, 512))
+    src_gcps = [
+        GroundControlPoint(row=0, col=0, x=156113, y=2818720, z=0),
+        GroundControlPoint(row=0, col=800, x=338353, y=2785790, z=0),
+        GroundControlPoint(row=800, col=800, x=297939, y=2618518, z=0),
+        GroundControlPoint(row=800, col=0, x=115698, y=2651448, z=0),
+    ]
+    reproject(
+        source,
+        out,
+        src_crs="EPSG:32618",
+        gcps=src_gcps,
+        dst_crs="EPSG:32618",
+        resampling=Resampling.nearest
+    )
+
+    assert not out.all()
+    assert not out[:, 0, 0].any()
+    assert not out[:, 0, -1].any()
+    assert not out[:, -1, -1].any()
+    assert not out[:, -1, 0].any()
+
+def test_warp_gcps_compute_dst_transform_automatically_reader(tmpdir):
+    """Ensure we don't raise an exception when gcps passed without dst_transform, for a source dataset"""
+    tiffname = str(tmpdir.join('test.tif'))
+    arr = np.ones((3, 800, 800), dtype=np.uint8) * 255
+    src_gcps = [
+        GroundControlPoint(row=0, col=0, x=156113, y=2818720, z=0),
+        GroundControlPoint(row=0, col=800, x=338353, y=2785790, z=0),
+        GroundControlPoint(row=800, col=800, x=297939, y=2618518, z=0),
+        GroundControlPoint(row=800, col=0, x=115698, y=2651448, z=0),
+    ]
+    out = np.zeros((3, 512, 512))
+
+    with rasterio.open(tiffname, mode='w', height=800, width=800, count=3, dtype=np.uint8) as source:
+        source.gcps = (src_gcps, CRS.from_epsg(32618))
+    
+    with rasterio.open(tiffname) as source:
+        reproject(
+            rasterio.band(source, source.indexes),
+            out,
+            dst_crs="EPSG:32618",
+            resampling=Resampling.nearest
+        )
+    
+    assert not out.all()
+    assert not out[:, 0, 0].any()
+    assert not out[:, 0, -1].any()
+    assert not out[:, -1, -1].any()
+    assert not out[:, -1, 0].any()
+
+def test_reproject_rpcs_exact_transformer(caplog):
+    """Reproject using rational polynomial coefficients and DEM, requiring that
+       we don't try to make an approximate transformer.
+    """
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        with rasterio.MemoryFile(dirname='foo', filename='dem.tif') as mem:
+            crs = 'COMPD_CS["WGS 84 + EGM96 height",GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AXIS["Latitude",NORTH],AXIS["Longitude",EAST],AUTHORITY["EPSG","4326"]],VERT_CS["EGM96 height",VERT_DATUM["EGM96 geoid",2005,AUTHORITY["EPSG","5171"]],UNIT["metre",1,AUTHORITY["EPSG","9001"]],AXIS["Gravity-related height",UP],AUTHORITY["EPSG","5773"]]]'
+            transform = Affine(0.001953396267361111, 0.0, -124.00013888888888, 0.0, -0.001953396267361111, 50.000138888888884)
+            with mem.open(
+                driver="GTiff",
+                width=1024, 
+                height=1024, 
+                count=1,
+                transform=transform,
+                dtype='int16', 
+                crs=crs
+            ) as dem:
+                # we flush dem dataset before letting GDAL read from vsimem
+                dem.write_band(1, 500 * np.ones((1024, 1024), dtype='int16'))
+            
+            out = np.zeros(
+                (3, src.profile["width"], src.profile["height"]), dtype=np.uint8
+            )
+            src_rpcs = src.rpcs
+            caplog.set_level(logging.DEBUG)
+            reproject(
+                rasterio.band(src, src.indexes),
+                out,
+                src_crs="EPSG:4326",
+                rpcs=src_rpcs,
+                dst_crs="EPSG:3857",
+                resampling=Resampling.nearest,
+                RPC_DEM=dem.name,
+            )   
+
+            assert "Created exact transformer" in caplog.text
+            
+
+def test_reproject_rpcs_approx_transformer(caplog):
+    """Reproject using rational polynomial coefficients without a DEM, for which it's
+       ok to use an approximate transformer.
+    """
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        out = np.zeros(
+                (3, src.profile["width"], src.profile["height"]), dtype=np.uint8
+            )
+        src_rpcs = src.rpcs
+        caplog.set_level(logging.DEBUG)
+        reproject(
+            rasterio.band(src, src.indexes),
+            out,
+            src_crs="EPSG:4326",
+            rpcs=src_rpcs,
+            dst_crs="EPSG:3857",
+            resampling=Resampling.nearest,
+        ) 
+
+        assert "Created approximate transformer" in caplog.text
\ No newline at end of file
