@@ -1,7 +1,9 @@
 import os
+import logging
 
 import pytest
 
+import rasterio
 from rasterio._warp import _calculate_default_transform
 from rasterio.control import GroundControlPoint
 from rasterio.crs import CRS
@@ -9,6 +11,7 @@ from rasterio.errors import CRSError
 from rasterio.transform import from_bounds
 from rasterio.warp import calculate_default_transform, transform_bounds
 
+log = logging.getLogger(__name__)
 
 def test_gcps_bounds_exclusivity():
     """gcps and bounds parameters are mutually exclusive"""
@@ -38,8 +41,8 @@ def test_dimensions_missing_params():
             resolution=1, dst_width=None, dst_height=1)
 
 
-def test_one_of_gcps_bounds():
-    """at least one of gcps or bounds parameters must be provided"""
+def test_one_of_gcps_rpcs_bounds():
+    """at least one of gcps, rpcs, or bounds parameters must be provided"""
     with pytest.raises(ValueError):
         calculate_default_transform(
             'epsg:4326', 'epsg:3857', width=1, height=1)
@@ -180,3 +183,27 @@ def test_issue1131():
     """Confirm that we don't run out of memory"""
     transform, w, h = calculate_default_transform(CRS.from_epsg(4326), CRS.from_epsg(3857), 455880, 454450, 13.0460235139, 42.6925552354, 13.2511695428, 42.8970561511)
     assert (w, h) == (381595, 518398)
+
+def test_rpcs_calculate_transform():
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        _, width, height = calculate_default_transform('EPSG:4326', 'EPSG:32610', width=7449, height=11522, rpcs=src.rpcs)
+        
+        assert width == 10889
+        assert height == 11579
+
+def test_rpcs_calculate_transform_pass_kwargs_to_transformer(caplog):
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        caplog.set_level(logging.DEBUG)
+        _, width, height = calculate_default_transform('EPSG:4326', 'EPSG:32610', width=7449, height=11522, rpcs=src.rpcs, RPC_HEIGHT=1000)
+        
+        assert "RPC_HEIGHT" in caplog.text
+        assert width == 10880
+        assert height == 11587
+
+def test_gcps_rpcs_exclusivity():
+    with pytest.raises(ValueError):
+        calculate_default_transform('EPSG:4326', 'EPSG:32610', width=7449, height=11522, gcps=[0], rpcs={'a':'123'})
+    
+def test_rpcs_bounds_exclusivity():
+    with pytest.raises(ValueError):
+        calculate_default_transform('EPSG:4326', 'EPSG:32610', width=7449, height=11522, left=1, rpcs={'a':'123'})
\ No newline at end of file
