@@ -1,4 +1,3 @@
-import logging
 import re
 import subprocess
 import sys
@@ -14,9 +13,6 @@ from rasterio.errors import RasterioIOError, DriverRegistrationError
 from rasterio._base import driver_supports_mode
 
 
-logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
-
-
 def test_validate_dtype_None(tmpdir):
     """Raise TypeError if there is no dtype"""
     name = str(tmpdir.join("lol.tif"))
@@ -353,7 +349,7 @@ def test_wplus_transform(tmpdir):
 
 
 def test_write_no_driver__issue_1203(tmpdir):
-    name = str(tmpdir.join("test.tif"))
+    name = str(tmpdir.join("test.invalid"))
     with pytest.raises(ValueError), rasterio.open(name, 'w', height=1, width=1, count=1, dtype='uint8'):
         print("TEST FAILED IF THIS IS REACHED.")
 
@@ -372,3 +368,37 @@ def test_too_big_for_tiff(tmpdir):
     name = str(tmpdir.join("test.tif"))
     with pytest.raises(RasterioIOError):
         rasterio.open(name, 'w', driver='GTiff', height=100000, width=100000, count=1, dtype='uint8', BIGTIFF=False)
+
+
+@pytest.mark.parametrize("extension, driver", [
+    ('tif', 'GTiff'),
+    ('tiff', 'GTiff'),
+    ('png', 'PNG'),
+    ('jpg', 'JPEG'),
+    ('jpeg', 'JPEG'),
+])
+def test_write__autodetect_driver(tmpdir, extension, driver):
+    name = str(tmpdir.join("test.{}".format(extension)))
+    with rasterio.open(name, 'w', height=1, width=1, count=1, dtype='uint8') as rds:
+        assert rds.driver == driver
+
+
+@pytest.mark.parametrize("driver", ["PNG", "JPEG"])
+def test_issue2088(tmpdir, capsys, driver):
+    """Write a PNG or JPEG without error messages"""
+    with rasterio.open(
+        str(tmpdir.join("test")),
+        "w",
+        driver=driver,
+        dtype="uint8",
+        count=1,
+        height=256,
+        width=256,
+        transform=affine.Affine.identity(),
+    ) as src:
+        data = np.ones((256, 256), dtype=np.uint8)
+        src.write(data, 1)
+
+    captured = capsys.readouterr()
+    assert "ERROR 4" not in captured.err
+    assert "ERROR 4" not in captured.out
